<?php
	/*
	 *
	 * 2003 - 2023 @ Yal Publicidad - yPanel
	 * www.yalpublicidad.com
	 * online@yalpublicidad.com
	 *
	 * formulario de modulo
	 */
	
	/* Autorizo acceso */
		defined('YPANEL_INI') or die( 'No dispones de acceso' );
		
	yPanel::incluir_css( com_base() . "css-entradas.css" );
	
	$tabla	= MYSQL_PREFIJO_SISX . 'contenido';
	$orden	= _mysql_contar_reg( $tabla, "id", NULL );
	$orden	= ( com_obtReg( "orden", 0 ) > 0 ) ? com_obtReg( "orden", 0 ) : ( $orden + 1 );
?>

			<script type="text/javascript" src="editor/tinymce/tinymce.min.js"></script>
			<script type="text/javascript" src="editor/yexplorador/js/jsy-script.js"></script>
			
			<style>
				.ft{ padding: 10px 0px; margin-top:25px; border-top:1px dashed #ccc; text-align:right; }
			</style>
			
			<script type="text/javascript">
			<!--
				
				var VentanaSurgir;
				
				wyeModalClose = function( Obj ){
					if( Obj == 'tinyMCE' )
						return tinyMCE.activeEditor.windowManager.close();
						
					if( Obj == 'Ventana' )
						return VentanaSurgir.window.close();
				}
				
				wyeInsertEditorTexto = function( texto )
				{
					tinyMCE.activeEditor.execCommand('mceInsertContent', false, texto);
				}
				
				insertarImgEditor = function( selector, imagen )
				{
					if( imagen.length < 5 ){ alert('Debes ingresar una ruta multimedia válida.'); return false; }
					var htmlImg = '<img src="' + imagen + '" alt="">';
					tinyMCE.activeEditor.execCommand('mceInsertContent', false, htmlImg);
					tinyMCE.activeEditor.windowManager.close();
					return;
				}
				
				insImg = function(selector,imagen){
					if( imagen == null ){
						alert('Seleccione una imagen');
					}else{
						document.getElementById(selector).value = imagen;
						$y.modal.cerrar();
						return;
					}
					//alert(selector);
					//alert(imagen);
				}
				
				tinymce.suffix = '.min';
				tinymce.baseURL = 'editor/tinymce';
				tinymce.init({
					language : '<?php echo yPanel::cuenta_usuario( 'lenguaje' ); ?>',
					selector: "textarea#edTexto",
					theme: "modern",
					schema: "html5",
		
					inline_styles : true,
					gecko_spellcheck : true,
					entity_encoding : "raw",
					verify_html: true,
					force_br_newlines : false, force_p_newlines : true, forced_root_block : 'p',
					toolbar_items_size: "small",
					
					relative_urls : true,
					remove_script_host : false,
					
					document_base_url : "<?php echo base_sitioWeby() ?>",
					
					//content_css: "ypanel/css/styles-editor.css",
					
					setup: function (editor) {
			
							!(function(){
								var getBtnOptions = new Function("return {handler: \'iframe\', size: {x: 800, y: 500}}"),
									btnOptions = getBtnOptions(),
									modalWidth = btnOptions.size && btnOptions.size.x ?  btnOptions.size.x : null,
									modalHeight = btnOptions.size && btnOptions.size.y ?  btnOptions.size.y : null;
								editor.addButton("button-2Imagen", {
									text: "Imagen",
									title: "Imagen",
									icon: "fa fa-picture-o",
									onclick: function () {
											var modalOptions = {
												title  : "Imagen",
												url: 'editor/yexplorador/?insImg=1&func_js=insertarImgEditor',
												buttons: [{
													text   : "Close",
													onclick: "close"
												}]
											}
											if(modalWidth){
												modalOptions.width = modalWidth;
											}
											if(modalHeight){
												modalOptions.height = modalHeight;
											}
											editor.windowManager.open(modalOptions);
									}
								});
							})();;
						},
					paste_data_images: true,
					
					valid_elements : "",
					extended_valid_elements : "hr[id|title|alt|class|width|size|noshade]", //iframe[src|style|width|height|scrolling|marginwidth|marginheight|frameborder],script[type|src]
					//invalid_elements : "script,applet,iframe",
					plugins : "print preview table image link media codesample table code hr charmap autolink visualblocks lists importcss jdragdrop",
					toolbar: "insertfile undo redo preview | bold italic underline strikethrough | alignleft aligncenter alignright alignjustify | formatselect | bullist numlist | outdent indent | link unlink anchor code | hr table | subscript superscript | charmap | button-2Imagen",
					removed_menuitems: "newdocument",
					
					importcss_append: true,
					
					resize: "both",
					height : "700"
 });
				
				/*function habilitar_marco_pu( elemento, resultado ){
					
					var indice = elemento.selectedIndex;
					
					if( indice < 1 ){
						resultado.disabled = true;
						resultado.classList.add('input-disabled');
						resultado.style.cursor = 'not-allowed';
					}else{
						resultado.disabled = false;
						resultado.classList.remove('input-disabled');
						resultado.style.cursor = '';
						
					}
				}*/

			//-->
			</script>
			
		<form method="post" action="<?php echo com_base() ?>prcss.php">
			<input type="hidden" name="post" value="<?php echo com_obtReg( "id", 0 ); ?>" >
			<input type="hidden" name="acc" value="g-posts">
			<!-- Botones -->
			<div align="right">
				<?php 
					echo com_boton( 'cerrar' ) . ' ' .
						com_boton( 'guardar', NULL ); 
				?>
			</div>
			<!-- / Botones -->
			
			<hr>
			
			<div class="row">
				<!-- Panel Principal -->
				<div class="col-sm-8">
					
					<div class="row m-b-10">
						<div class="col-sm-12"><input type="text" id="titulo" name="titulo" placeholder="<?php echo etiqueta( 'e_agregar_titulo', 'Agregar título' ) ?>" value="<?php echo com_obtReg( "titulo" ) ?>"></div>
					</div>
					<div class="row m-b-10">
						<div class="col-sm-12">
							<label for="slug">URL Slug</label>
							<input type="text" id="slug" name="slug" class="w-full" value="<?php echo com_obtReg( "slug" ) ?>" onFocus="oSlug(this.form)">
						</div>
					</div>
					<div>
						<pre id="eEditorTA2" style="display:none;"><?php echo com_obtReg( "texto" ); ?></pre>
						<textarea id="edTexto" name="texto"></textarea>
						<script> document.getElementById('edTexto').value = document.getElementById('eEditorTA2').innerHTML; </script>
					</div>					
				
				</div>
				
				<!-- Opciones de publicacion -->
				<div class="col-sm-4">
					<fieldset class="fs-small">
						<legend><?php echo etiqueta( 'legend_entradas_1', 'Opciones de Publicación' ) ?></legend>
						<div class="m-b-10">
							<label class="texto"><?php echo etiqueta( 'e_editado_por', 'Editado por' ) ?>:</label> 
							<strong><?php echo (!empty( e_autor( com_obtReg( "autor" ) ) ) ) ? e_autor( com_obtReg( "autor" ) ) : yPanel::usuario(); ?></strong>
						</div>
						<div class="m-b-10">
							<label><?php echo etiqueta( 'e_publicado', 'Publicado' ) ?></label>
							<div class="dis-inline-block"><?php echo com_btnToggle( 'publicado', 1, com_obtReg( "publicado", 1 ) ); ?></div>
						</div>
						<div class="m-b-20">
							<input type="text" id="codigo" name="codigo" placeholder="<?php echo etiqueta( 'e_codigo', 'Código de publicacion' ) ?>" value="<?php echo com_obtReg( "codnum" ) ?>">
						</div>
						<div class="m-b-5">
							<textarea id="descripcion" name="descripcion" placeholder="<?php echo etiqueta( 'e_descripcion_corta', 'Descripción Corta' ) ?>" maxlength="1255"><?php echo com_obtReg( "textocorto" ) ?></textarea>
						</div>
						<div class="m-b-10">
							<label class="texto" for="orden"><?php echo etiqueta( 'e_orden', 'Orden' ) ?></label> 
							<input type="number" id="orden" name="orden" value="<?php echo $orden; //com_obtReg( "orden", 0 ) ?>">
						</div>
						
						<hr>
						
						<div class="m-b-10">
							<label for="seccion"><?php echo etiqueta( 'e_seccion', 'Sección' ) ?></label><br>
							<?php
								echo secciones();
							?>
						</div>
						<div class="m-b-10">
							<label for="categoria"><?php echo etiqueta( 'e_categoria', 'Categoría' ) ?></label><br>
							<?php
								echo categorias();
							?>
						</div>
						<div class="m-b-10">
							<label for="jerarquia"><?php echo etiqueta( 'e_dependencia', 'Dependencia' ) ?></label><br>
							<?php
								echo dependencia();
							?>
						</div>
						
						<hr>
						
						<div class="m-b-10">
							<label for="tags">Tags</label>
							<input type="text" class="w-full" id="tags" name="tags" value="<?php echo com_obtReg( "tags" ) ?>" maxlength="200">
						</div>
						
						<hr>
						
						<div class="m-b-10">
							<label for="imagen_entrada"><?php echo etiqueta( 'e_img_portada', 'Imagen de portada' ) ?></label>
							<input type="text" class="w-full" id="imagen_entrada" name="imagen_entrada" value="<?php echo com_obtReg( "imagenpost" ) ?>">
							<button type="button" onClick="$y.modal.abrir({url:'editor/yexplorador/?insImg=1&func_js=insImg&selector=imagen_entrada'})"><?php echo etiqueta( 'b_sel_imagen', 'Seleccionar imagen' ) ?></button>
						</div>
						<div class="m-b-10">
							<label for="imagenes_entrada"><?php echo etiqueta( 'e_img_adicionales', 'Imágenes adicionales' ) ?></label>
							<textarea class="w-full" id="imagenes_entrada" name="imagenes_entrada"><?php echo com_obtReg( "imagenes" ) ?></textarea>
							<button type="button" onClick="$y.modal.abrir({url:'editor/yexplorador/?insImg=1&func_js=insImg&selector=imagenes_entrada'})"><?php echo etiqueta( 'b_sel_imagen', 'Seleccionar imagen' ) ?></button>
						</div>
						<div class="m-b-10">
							<label for="video"><?php echo etiqueta( 'e_watch_youtube', 'Video de YouTube' ) ?></label>
							<input type="text" class="w-full" id="video" name="video" placeholder="ej. https://www.youtube.com/watch?v=pzBkSSEt8RI" value="<?php echo com_obtReg( "video_youtube" ) ?>" maxlength="200">
						</div>
						
						<hr>
												
						<div>
							<input type="number" id="precio" name="precio" placeholder="<?php echo etiqueta( 'e_precio', 'Importe' ) ?>" value="<?php echo com_obtReg( "precio" ) ?>">
							<input type="text" id="descuento" name="descuento" placeholder="<?php echo etiqueta( 'e_descuento', 'Descuento' ) ?>" value="<?php echo com_obtReg( "descuento" ) ?>">
						</div>
					</fieldset>
				</div>
			</div>
		</form>
		
		<script>
			function obtCadenaSlug(cadena){
			   // Definimos los caracteres que queremos eliminar
			   var specialChars = "!¡@#$^&%*()+=_[]\/{}|:<>?¿,.";
			   
			   cadena = cadena.trim();
			
			   // Los eliminamos todos
			   for (var i = 0; i < specialChars.length; i++) {
				   cadena= cadena.replace(new RegExp("\\" + specialChars[i], 'gi'), '');
			   }   
			
			   // Lo queremos devolver limpio en minusculas
			   cadena = cadena.toLowerCase();
			
			   // Quitamos espacios y los sustituimos por - porque nos gusta mas asi
			   cadena = cadena.replace(/ /g,"-");
			
			   // Quitamos acentos y "ñ". Fijate en que va sin comillas el primer parametro
			   cadena = cadena.replace(/á/gi,"a");
			   cadena = cadena.replace(/é/gi,"e");
			   cadena = cadena.replace(/í/gi,"i");
			   cadena = cadena.replace(/ó/gi,"o");
			   cadena = cadena.replace(/ú/gi,"u");
			   cadena = cadena.replace(/ñ/gi,"n");
			   return cadena;
			}
			
			//** validar formulario */
				$_("#guardar").onclick = function(){
					f = this.form;
					if( f.titulo.value.length < 6 ){
						f.titulo.focus();
						MsjBox.mostrar( '<?php echo etiqueta( 'msj_err_titulo', 'Por favor ingrese un título válido.' ) ?>' );
						return false
					}
					if( f.slug.value.length < 3 ){
						f.slug.value = obtCadenaSlug(f.titulo.value);
					}
					tinyMCE.triggerSave();
					//var texto = window.btoa( obtContenidoiFrame( 'eEditorTextArea_ifr' ) );
					eform( this.form );
					
					return false;
				}
				
			//** slug
				oSlug = function(f){
					if( f.slug.value.length < 3 ){
						f.slug.value = obtCadenaSlug(f.titulo.value);
					}
				}
			//** Boton cancelar */
				$_("#cerrar").onclick = function(){ history.go(-1); }
			
		</script>